"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import tendermint.types.evidence_pb2
import tendermint.types.types_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Block(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    EVIDENCE_FIELD_NUMBER: builtins.int
    LAST_COMMIT_FIELD_NUMBER: builtins.int

    @property
    def header(self) -> tendermint.types.types_pb2.Header: ...

    @property
    def data(self) -> tendermint.types.types_pb2.Data: ...

    @property
    def evidence(self) -> tendermint.types.evidence_pb2.EvidenceList: ...

    @property
    def last_commit(self) -> tendermint.types.types_pb2.Commit: ...

    def __init__(self,
        *,
        header : typing.Optional[tendermint.types.types_pb2.Header] = ...,
        data : typing.Optional[tendermint.types.types_pb2.Data] = ...,
        evidence : typing.Optional[tendermint.types.evidence_pb2.EvidenceList] = ...,
        last_commit : typing.Optional[tendermint.types.types_pb2.Commit] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"evidence",b"evidence",u"header",b"header",u"last_commit",b"last_commit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"evidence",b"evidence",u"header",b"header",u"last_commit",b"last_commit"]) -> None: ...
global___Block = Block



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.core.connection.v1.connection_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTIONS_FIELD_NUMBER: builtins.int
    CLIENT_CONNECTION_PATHS_FIELD_NUMBER: builtins.int
    NEXT_CONNECTION_SEQUENCE_FIELD_NUMBER: builtins.int
    next_connection_sequence: builtins.int = ...

    @property
    def connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.connection.v1.connection_pb2.IdentifiedConnection]: ...

    @property
    def client_connection_paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.connection.v1.connection_pb2.ConnectionPaths]: ...

    def __init__(self,
        *,
        connections : typing.Optional[typing.Iterable[ibc.core.connection.v1.connection_pb2.IdentifiedConnection]] = ...,
        client_connection_paths : typing.Optional[typing.Iterable[ibc.core.connection.v1.connection_pb2.ConnectionPaths]] = ...,
        next_connection_sequence : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_connection_paths",b"client_connection_paths",u"connections",b"connections",u"next_connection_sequence",b"next_connection_sequence"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Capability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    index: builtins.int = ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index"]) -> None: ...
global___Capability = Capability

class Owner(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MODULE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    module: typing.Text = ...
    name: typing.Text = ...

    def __init__(self,
        *,
        module : typing.Text = ...,
        name : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"module",b"module",u"name",b"name"]) -> None: ...
global___Owner = Owner

class CapabilityOwners(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OWNERS_FIELD_NUMBER: builtins.int

    @property
    def owners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Owner]: ...

    def __init__(self,
        *,
        owners : typing.Optional[typing.Iterable[global___Owner]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"owners",b"owners"]) -> None: ...
global___CapabilityOwners = CapabilityOwners



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyband",
    packages=setuptools.find_packages(),
    include_package_data=True,
    version="0.2.5",
    license="MIT",
    description="Python library for BandChain",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Band Protocol",
    author_email="dev@bandprotocol.com",
    url="https://github.com/bandprotocol/bandchain",
    keywords=["BAND", "BLOCKCHAIN", "ORACLE"],
    install_requires=["requests", "dacite", "bech32", "bip32", "ecdsa", "mnemonic", "grpcio"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SnapshotItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STORE_FIELD_NUMBER: builtins.int
    IAVL_FIELD_NUMBER: builtins.int

    @property
    def store(self) -> global___SnapshotStoreItem: ...

    @property
    def iavl(self) -> global___SnapshotIAVLItem: ...

    def __init__(self,
        *,
        store : typing.Optional[global___SnapshotStoreItem] = ...,
        iavl : typing.Optional[global___SnapshotIAVLItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"iavl",b"iavl",u"item",b"item",u"store",b"store"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"iavl",b"iavl",u"item",b"item",u"store",b"store"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"item",b"item"]) -> typing.Optional[typing_extensions.Literal["store","iavl"]]: ...
global___SnapshotItem = SnapshotItem

class SnapshotStoreItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"name",b"name"]) -> None: ...
global___SnapshotStoreItem = SnapshotStoreItem

class SnapshotIAVLItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    value: builtins.bytes = ...
    version: builtins.int = ...
    height: builtins.int = ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        value : builtins.bytes = ...,
        version : builtins.int = ...,
        height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"key",b"key",u"value",b"value",u"version",b"version"]) -> None: ...
global___SnapshotIAVLItem = SnapshotIAVLItem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    SetWithdrawAddress:grpc.UnaryUnaryMultiCallable[
        global___MsgSetWithdrawAddress,
        global___MsgSetWithdrawAddressResponse] = ...

    WithdrawDelegatorReward:grpc.UnaryUnaryMultiCallable[
        global___MsgWithdrawDelegatorReward,
        global___MsgWithdrawDelegatorRewardResponse] = ...

    WithdrawValidatorCommission:grpc.UnaryUnaryMultiCallable[
        global___MsgWithdrawValidatorCommission,
        global___MsgWithdrawValidatorCommissionResponse] = ...

    FundCommunityPool:grpc.UnaryUnaryMultiCallable[
        global___MsgFundCommunityPool,
        global___MsgFundCommunityPoolResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SetWithdrawAddress(self,
        request: global___MsgSetWithdrawAddress,
        context: grpc.ServicerContext,
    ) -> global___MsgSetWithdrawAddressResponse: ...

    @abc.abstractmethod
    def WithdrawDelegatorReward(self,
        request: global___MsgWithdrawDelegatorReward,
        context: grpc.ServicerContext,
    ) -> global___MsgWithdrawDelegatorRewardResponse: ...

    @abc.abstractmethod
    def WithdrawValidatorCommission(self,
        request: global___MsgWithdrawValidatorCommission,
        context: grpc.ServicerContext,
    ) -> global___MsgWithdrawValidatorCommissionResponse: ...

    @abc.abstractmethod
    def FundCommunityPool(self,
        request: global___MsgFundCommunityPool,
        context: grpc.ServicerContext,
    ) -> global___MsgFundCommunityPoolResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from oracle.v1 import tx_pb2 as oracle_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the oracle Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RequestData = channel.unary_unary(
                '/oracle.v1.Msg/RequestData',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgRequestData.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgRequestDataResponse.FromString,
                )
        self.ReportData = channel.unary_unary(
                '/oracle.v1.Msg/ReportData',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgReportData.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgReportDataResponse.FromString,
                )
        self.CreateDataSource = channel.unary_unary(
                '/oracle.v1.Msg/CreateDataSource',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgCreateDataSource.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgCreateDataSourceResponse.FromString,
                )
        self.EditDataSource = channel.unary_unary(
                '/oracle.v1.Msg/EditDataSource',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgEditDataSource.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgEditDataSourceResponse.FromString,
                )
        self.CreateOracleScript = channel.unary_unary(
                '/oracle.v1.Msg/CreateOracleScript',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgCreateOracleScript.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgCreateOracleScriptResponse.FromString,
                )
        self.EditOracleScript = channel.unary_unary(
                '/oracle.v1.Msg/EditOracleScript',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgEditOracleScript.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgEditOracleScriptResponse.FromString,
                )
        self.Activate = channel.unary_unary(
                '/oracle.v1.Msg/Activate',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgActivate.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgActivateResponse.FromString,
                )
        self.AddReporter = channel.unary_unary(
                '/oracle.v1.Msg/AddReporter',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgAddReporter.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgAddReporterResponse.FromString,
                )
        self.RemoveReporter = channel.unary_unary(
                '/oracle.v1.Msg/RemoveReporter',
                request_serializer=oracle_dot_v1_dot_tx__pb2.MsgRemoveReporter.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_tx__pb2.MsgRemoveReporterResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the oracle Msg service.
    """

    def RequestData(self, request, context):
        """RequestData defines a method for submitting a new request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportData(self, request, context):
        """ReportData defines a method for reporting a data to resolve the request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataSource(self, request, context):
        """CreateDataSource defines a method for creating a new data source.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditDataSource(self, request, context):
        """EditDataSource defines a method for editing an existing data source.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOracleScript(self, request, context):
        """CreateOracleScript defines a method for creating a new oracle script.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditOracleScript(self, request, context):
        """EditOracleScript defines a method for editing an existing oracle script.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Activate defines a method for applying to be an oracle validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddReporter(self, request, context):
        """AddReporter defines a method for adding a new reporter for a validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveReporter(self, request, context):
        """RemoveReporter defines a method for removing an reporter from a validator
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RequestData': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestData,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgRequestData.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgRequestDataResponse.SerializeToString,
            ),
            'ReportData': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportData,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgReportData.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgReportDataResponse.SerializeToString,
            ),
            'CreateDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataSource,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgCreateDataSource.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgCreateDataSourceResponse.SerializeToString,
            ),
            'EditDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.EditDataSource,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgEditDataSource.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgEditDataSourceResponse.SerializeToString,
            ),
            'CreateOracleScript': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOracleScript,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgCreateOracleScript.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgCreateOracleScriptResponse.SerializeToString,
            ),
            'EditOracleScript': grpc.unary_unary_rpc_method_handler(
                    servicer.EditOracleScript,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgEditOracleScript.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgEditOracleScriptResponse.SerializeToString,
            ),
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgActivate.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgActivateResponse.SerializeToString,
            ),
            'AddReporter': grpc.unary_unary_rpc_method_handler(
                    servicer.AddReporter,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgAddReporter.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgAddReporterResponse.SerializeToString,
            ),
            'RemoveReporter': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveReporter,
                    request_deserializer=oracle_dot_v1_dot_tx__pb2.MsgRemoveReporter.FromString,
                    response_serializer=oracle_dot_v1_dot_tx__pb2.MsgRemoveReporterResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oracle.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the oracle Msg service.
    """

    @staticmethod
    def RequestData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/RequestData',
            oracle_dot_v1_dot_tx__pb2.MsgRequestData.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgRequestDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/ReportData',
            oracle_dot_v1_dot_tx__pb2.MsgReportData.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgReportDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/CreateDataSource',
            oracle_dot_v1_dot_tx__pb2.MsgCreateDataSource.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgCreateDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/EditDataSource',
            oracle_dot_v1_dot_tx__pb2.MsgEditDataSource.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgEditDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOracleScript(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/CreateOracleScript',
            oracle_dot_v1_dot_tx__pb2.MsgCreateOracleScript.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgCreateOracleScriptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditOracleScript(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/EditOracleScript',
            oracle_dot_v1_dot_tx__pb2.MsgEditOracleScript.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgEditOracleScriptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/Activate',
            oracle_dot_v1_dot_tx__pb2.MsgActivate.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgActivateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddReporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/AddReporter',
            oracle_dot_v1_dot_tx__pb2.MsgAddReporter.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgAddReporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveReporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Msg/RemoveReporter',
            oracle_dot_v1_dot_tx__pb2.MsgRemoveReporter.SerializeToString,
            oracle_dot_v1_dot_tx__pb2.MsgRemoveReporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Proposal:grpc.UnaryUnaryMultiCallable[
        global___QueryProposalRequest,
        global___QueryProposalResponse] = ...

    Proposals:grpc.UnaryUnaryMultiCallable[
        global___QueryProposalsRequest,
        global___QueryProposalsResponse] = ...

    Vote:grpc.UnaryUnaryMultiCallable[
        global___QueryVoteRequest,
        global___QueryVoteResponse] = ...

    Votes:grpc.UnaryUnaryMultiCallable[
        global___QueryVotesRequest,
        global___QueryVotesResponse] = ...

    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...

    Deposit:grpc.UnaryUnaryMultiCallable[
        global___QueryDepositRequest,
        global___QueryDepositResponse] = ...

    Deposits:grpc.UnaryUnaryMultiCallable[
        global___QueryDepositsRequest,
        global___QueryDepositsResponse] = ...

    TallyResult:grpc.UnaryUnaryMultiCallable[
        global___QueryTallyResultRequest,
        global___QueryTallyResultResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Proposal(self,
        request: global___QueryProposalRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryProposalResponse: ...

    @abc.abstractmethod
    def Proposals(self,
        request: global___QueryProposalsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryProposalsResponse: ...

    @abc.abstractmethod
    def Vote(self,
        request: global___QueryVoteRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryVoteResponse: ...

    @abc.abstractmethod
    def Votes(self,
        request: global___QueryVotesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryVotesResponse: ...

    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...

    @abc.abstractmethod
    def Deposit(self,
        request: global___QueryDepositRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDepositResponse: ...

    @abc.abstractmethod
    def Deposits(self,
        request: global___QueryDepositsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDepositsResponse: ...

    @abc.abstractmethod
    def TallyResult(self,
        request: global___QueryTallyResultRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryTallyResultResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import tendermint.types.types_pb2
import tendermint.types.validator_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Evidence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DUPLICATE_VOTE_EVIDENCE_FIELD_NUMBER: builtins.int
    LIGHT_CLIENT_ATTACK_EVIDENCE_FIELD_NUMBER: builtins.int

    @property
    def duplicate_vote_evidence(self) -> global___DuplicateVoteEvidence: ...

    @property
    def light_client_attack_evidence(self) -> global___LightClientAttackEvidence: ...

    def __init__(self,
        *,
        duplicate_vote_evidence : typing.Optional[global___DuplicateVoteEvidence] = ...,
        light_client_attack_evidence : typing.Optional[global___LightClientAttackEvidence] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"duplicate_vote_evidence",b"duplicate_vote_evidence",u"light_client_attack_evidence",b"light_client_attack_evidence",u"sum",b"sum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"duplicate_vote_evidence",b"duplicate_vote_evidence",u"light_client_attack_evidence",b"light_client_attack_evidence",u"sum",b"sum"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"sum",b"sum"]) -> typing.Optional[typing_extensions.Literal["duplicate_vote_evidence","light_client_attack_evidence"]]: ...
global___Evidence = Evidence

class DuplicateVoteEvidence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTE_A_FIELD_NUMBER: builtins.int
    VOTE_B_FIELD_NUMBER: builtins.int
    TOTAL_VOTING_POWER_FIELD_NUMBER: builtins.int
    VALIDATOR_POWER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    total_voting_power: builtins.int = ...
    validator_power: builtins.int = ...

    @property
    def vote_a(self) -> tendermint.types.types_pb2.Vote: ...

    @property
    def vote_b(self) -> tendermint.types.types_pb2.Vote: ...

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        vote_a : typing.Optional[tendermint.types.types_pb2.Vote] = ...,
        vote_b : typing.Optional[tendermint.types.types_pb2.Vote] = ...,
        total_voting_power : builtins.int = ...,
        validator_power : builtins.int = ...,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"timestamp",b"timestamp",u"vote_a",b"vote_a",u"vote_b",b"vote_b"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"timestamp",b"timestamp",u"total_voting_power",b"total_voting_power",u"validator_power",b"validator_power",u"vote_a",b"vote_a",u"vote_b",b"vote_b"]) -> None: ...
global___DuplicateVoteEvidence = DuplicateVoteEvidence

class LightClientAttackEvidence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONFLICTING_BLOCK_FIELD_NUMBER: builtins.int
    COMMON_HEIGHT_FIELD_NUMBER: builtins.int
    BYZANTINE_VALIDATORS_FIELD_NUMBER: builtins.int
    TOTAL_VOTING_POWER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    common_height: builtins.int = ...
    total_voting_power: builtins.int = ...

    @property
    def conflicting_block(self) -> tendermint.types.types_pb2.LightBlock: ...

    @property
    def byzantine_validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[tendermint.types.validator_pb2.Validator]: ...

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        conflicting_block : typing.Optional[tendermint.types.types_pb2.LightBlock] = ...,
        common_height : builtins.int = ...,
        byzantine_validators : typing.Optional[typing.Iterable[tendermint.types.validator_pb2.Validator]] = ...,
        total_voting_power : builtins.int = ...,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"conflicting_block",b"conflicting_block",u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"byzantine_validators",b"byzantine_validators",u"common_height",b"common_height",u"conflicting_block",b"conflicting_block",u"timestamp",b"timestamp",u"total_voting_power",b"total_voting_power"]) -> None: ...
global___LightClientAttackEvidence = LightClientAttackEvidence

class EvidenceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EVIDENCE_FIELD_NUMBER: builtins.int

    @property
    def evidence(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Evidence]: ...

    def __init__(self,
        *,
        evidence : typing.Optional[typing.Iterable[global___Evidence]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"evidence",b"evidence"]) -> None: ...
global___EvidenceList = EvidenceList



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Send:grpc.UnaryUnaryMultiCallable[
        global___MsgSend,
        global___MsgSendResponse] = ...

    MultiSend:grpc.UnaryUnaryMultiCallable[
        global___MsgMultiSend,
        global___MsgMultiSendResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Send(self,
        request: global___MsgSend,
        context: grpc.ServicerContext,
    ) -> global___MsgSendResponse: ...

    @abc.abstractmethod
    def MultiSend(self,
        request: global___MsgMultiSend,
        context: grpc.ServicerContext,
    ) -> global___MsgMultiSendResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CurrentPlan:grpc.UnaryUnaryMultiCallable[
        global___QueryCurrentPlanRequest,
        global___QueryCurrentPlanResponse] = ...

    AppliedPlan:grpc.UnaryUnaryMultiCallable[
        global___QueryAppliedPlanRequest,
        global___QueryAppliedPlanResponse] = ...

    UpgradedConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryUpgradedConsensusStateRequest,
        global___QueryUpgradedConsensusStateResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CurrentPlan(self,
        request: global___QueryCurrentPlanRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryCurrentPlanResponse: ...

    @abc.abstractmethod
    def AppliedPlan(self,
        request: global___QueryAppliedPlanRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryAppliedPlanResponse: ...

    @abc.abstractmethod
    def UpgradedConsensusState(self,
        request: global___QueryUpgradedConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUpgradedConsensusStateResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    SubmitProposal:grpc.UnaryUnaryMultiCallable[
        global___MsgSubmitProposal,
        global___MsgSubmitProposalResponse] = ...

    Vote:grpc.UnaryUnaryMultiCallable[
        global___MsgVote,
        global___MsgVoteResponse] = ...

    Deposit:grpc.UnaryUnaryMultiCallable[
        global___MsgDeposit,
        global___MsgDepositResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SubmitProposal(self,
        request: global___MsgSubmitProposal,
        context: grpc.ServicerContext,
    ) -> global___MsgSubmitProposalResponse: ...

    @abc.abstractmethod
    def Vote(self,
        request: global___MsgVote,
        context: grpc.ServicerContext,
    ) -> global___MsgVoteResponse: ...

    @abc.abstractmethod
    def Deposit(self,
        request: global___MsgDeposit,
        context: grpc.ServicerContext,
    ) -> global___MsgDepositResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Account:grpc.UnaryUnaryMultiCallable[
        global___QueryAccountRequest,
        global___QueryAccountResponse] = ...

    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Account(self,
        request: global___QueryAccountRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryAccountResponse: ...

    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .types_pb2 import *
class ABCIApplicationStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Echo:grpc.UnaryUnaryMultiCallable[
        global___RequestEcho,
        global___ResponseEcho] = ...

    Flush:grpc.UnaryUnaryMultiCallable[
        global___RequestFlush,
        global___ResponseFlush] = ...

    Info:grpc.UnaryUnaryMultiCallable[
        global___RequestInfo,
        global___ResponseInfo] = ...

    SetOption:grpc.UnaryUnaryMultiCallable[
        global___RequestSetOption,
        global___ResponseSetOption] = ...

    DeliverTx:grpc.UnaryUnaryMultiCallable[
        global___RequestDeliverTx,
        global___ResponseDeliverTx] = ...

    CheckTx:grpc.UnaryUnaryMultiCallable[
        global___RequestCheckTx,
        global___ResponseCheckTx] = ...

    Query:grpc.UnaryUnaryMultiCallable[
        global___RequestQuery,
        global___ResponseQuery] = ...

    Commit:grpc.UnaryUnaryMultiCallable[
        global___RequestCommit,
        global___ResponseCommit] = ...

    InitChain:grpc.UnaryUnaryMultiCallable[
        global___RequestInitChain,
        global___ResponseInitChain] = ...

    BeginBlock:grpc.UnaryUnaryMultiCallable[
        global___RequestBeginBlock,
        global___ResponseBeginBlock] = ...

    EndBlock:grpc.UnaryUnaryMultiCallable[
        global___RequestEndBlock,
        global___ResponseEndBlock] = ...

    ListSnapshots:grpc.UnaryUnaryMultiCallable[
        global___RequestListSnapshots,
        global___ResponseListSnapshots] = ...

    OfferSnapshot:grpc.UnaryUnaryMultiCallable[
        global___RequestOfferSnapshot,
        global___ResponseOfferSnapshot] = ...

    LoadSnapshotChunk:grpc.UnaryUnaryMultiCallable[
        global___RequestLoadSnapshotChunk,
        global___ResponseLoadSnapshotChunk] = ...

    ApplySnapshotChunk:grpc.UnaryUnaryMultiCallable[
        global___RequestApplySnapshotChunk,
        global___ResponseApplySnapshotChunk] = ...


class ABCIApplicationServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Echo(self,
        request: global___RequestEcho,
        context: grpc.ServicerContext,
    ) -> global___ResponseEcho: ...

    @abc.abstractmethod
    def Flush(self,
        request: global___RequestFlush,
        context: grpc.ServicerContext,
    ) -> global___ResponseFlush: ...

    @abc.abstractmethod
    def Info(self,
        request: global___RequestInfo,
        context: grpc.ServicerContext,
    ) -> global___ResponseInfo: ...

    @abc.abstractmethod
    def SetOption(self,
        request: global___RequestSetOption,
        context: grpc.ServicerContext,
    ) -> global___ResponseSetOption: ...

    @abc.abstractmethod
    def DeliverTx(self,
        request: global___RequestDeliverTx,
        context: grpc.ServicerContext,
    ) -> global___ResponseDeliverTx: ...

    @abc.abstractmethod
    def CheckTx(self,
        request: global___RequestCheckTx,
        context: grpc.ServicerContext,
    ) -> global___ResponseCheckTx: ...

    @abc.abstractmethod
    def Query(self,
        request: global___RequestQuery,
        context: grpc.ServicerContext,
    ) -> global___ResponseQuery: ...

    @abc.abstractmethod
    def Commit(self,
        request: global___RequestCommit,
        context: grpc.ServicerContext,
    ) -> global___ResponseCommit: ...

    @abc.abstractmethod
    def InitChain(self,
        request: global___RequestInitChain,
        context: grpc.ServicerContext,
    ) -> global___ResponseInitChain: ...

    @abc.abstractmethod
    def BeginBlock(self,
        request: global___RequestBeginBlock,
        context: grpc.ServicerContext,
    ) -> global___ResponseBeginBlock: ...

    @abc.abstractmethod
    def EndBlock(self,
        request: global___RequestEndBlock,
        context: grpc.ServicerContext,
    ) -> global___ResponseEndBlock: ...

    @abc.abstractmethod
    def ListSnapshots(self,
        request: global___RequestListSnapshots,
        context: grpc.ServicerContext,
    ) -> global___ResponseListSnapshots: ...

    @abc.abstractmethod
    def OfferSnapshot(self,
        request: global___RequestOfferSnapshot,
        context: grpc.ServicerContext,
    ) -> global___ResponseOfferSnapshot: ...

    @abc.abstractmethod
    def LoadSnapshotChunk(self,
        request: global___RequestLoadSnapshotChunk,
        context: grpc.ServicerContext,
    ) -> global___ResponseLoadSnapshotChunk: ...

    @abc.abstractmethod
    def ApplySnapshotChunk(self,
        request: global___RequestApplySnapshotChunk,
        context: grpc.ServicerContext,
    ) -> global___ResponseApplySnapshotChunk: ...


def add_ABCIApplicationServicer_to_server(servicer: ABCIApplicationServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.applications.transfer.v1.transfer_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    DENOM_TRACES_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...

    @property
    def denom_traces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.applications.transfer.v1.transfer_pb2.DenomTrace]: ...

    @property
    def params(self) -> ibc.applications.transfer.v1.transfer_pb2.Params: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        denom_traces : typing.Optional[typing.Iterable[ibc.applications.transfer.v1.transfer_pb2.DenomTrace]] = ...,
        params : typing.Optional[ibc.applications.transfer.v1.transfer_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom_traces",b"denom_traces",u"params",b"params",u"port_id",b"port_id"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ListAllInterfacesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___ListAllInterfacesRequest = ListAllInterfacesRequest

class ListAllInterfacesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INTERFACE_NAMES_FIELD_NUMBER: builtins.int

    @property
    def interface_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        interface_names : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"interface_names",b"interface_names"]) -> None: ...
global___ListAllInterfacesResponse = ListAllInterfacesResponse

class ListImplementationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INTERFACE_NAME_FIELD_NUMBER: builtins.int
    interface_name: typing.Text = ...

    def __init__(self,
        *,
        interface_name : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"interface_name",b"interface_name"]) -> None: ...
global___ListImplementationsRequest = ListImplementationsRequest

class ListImplementationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IMPLEMENTATION_MESSAGE_NAMES_FIELD_NUMBER: builtins.int

    @property
    def implementation_message_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        implementation_message_names : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"implementation_message_names",b"implementation_message_names"]) -> None: ...
global___ListImplementationsResponse = ListImplementationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import oracle.v1.oracle_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryCountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryCountsRequest = QueryCountsRequest

class QueryCountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_COUNT_FIELD_NUMBER: builtins.int
    ORACLE_SCRIPT_COUNT_FIELD_NUMBER: builtins.int
    REQUEST_COUNT_FIELD_NUMBER: builtins.int
    data_source_count: builtins.int = ...
    oracle_script_count: builtins.int = ...
    request_count: builtins.int = ...

    def __init__(self,
        *,
        data_source_count : builtins.int = ...,
        oracle_script_count : builtins.int = ...,
        request_count : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source_count",b"data_source_count",u"oracle_script_count",b"oracle_script_count",u"request_count",b"request_count"]) -> None: ...
global___QueryCountsResponse = QueryCountsResponse

class QueryDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_HASH_FIELD_NUMBER: builtins.int
    data_hash: typing.Text = ...

    def __init__(self,
        *,
        data_hash : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_hash",b"data_hash"]) -> None: ...
global___QueryDataRequest = QueryDataRequest

class QueryDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...

    def __init__(self,
        *,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> None: ...
global___QueryDataResponse = QueryDataResponse

class QueryDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    data_source_id: builtins.int = ...

    def __init__(self,
        *,
        data_source_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source_id",b"data_source_id"]) -> None: ...
global___QueryDataSourceRequest = QueryDataSourceRequest

class QueryDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_FIELD_NUMBER: builtins.int

    @property
    def data_source(self) -> oracle.v1.oracle_pb2.DataSource: ...

    def __init__(self,
        *,
        data_source : typing.Optional[oracle.v1.oracle_pb2.DataSource] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data_source",b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source",b"data_source"]) -> None: ...
global___QueryDataSourceResponse = QueryDataSourceResponse

class QueryOracleScriptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"oracle_script_id",b"oracle_script_id"]) -> None: ...
global___QueryOracleScriptRequest = QueryOracleScriptRequest

class QueryOracleScriptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_FIELD_NUMBER: builtins.int

    @property
    def oracle_script(self) -> oracle.v1.oracle_pb2.OracleScript: ...

    def __init__(self,
        *,
        oracle_script : typing.Optional[oracle.v1.oracle_pb2.OracleScript] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"oracle_script",b"oracle_script"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"oracle_script",b"oracle_script"]) -> None: ...
global___QueryOracleScriptResponse = QueryOracleScriptResponse

class QueryRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.int = ...

    def __init__(self,
        *,
        request_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request_id",b"request_id"]) -> None: ...
global___QueryRequestRequest = QueryRequestRequest

class QueryRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_FIELD_NUMBER: builtins.int
    REPORTS_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int

    @property
    def request(self) -> oracle.v1.oracle_pb2.Request: ...

    @property
    def reports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.Report]: ...

    @property
    def result(self) -> oracle.v1.oracle_pb2.Result: ...

    def __init__(self,
        *,
        request : typing.Optional[oracle.v1.oracle_pb2.Request] = ...,
        reports : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.Report]] = ...,
        result : typing.Optional[oracle.v1.oracle_pb2.Result] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"request",b"request",u"result",b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reports",b"reports",u"request",b"request",u"result",b"result"]) -> None: ...
global___QueryRequestResponse = QueryRequestResponse

class QueryPendingRequestsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryPendingRequestsRequest = QueryPendingRequestsRequest

class QueryPendingRequestsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_IDS_FIELD_NUMBER: builtins.int

    @property
    def request_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    def __init__(self,
        *,
        request_ids : typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request_ids",b"request_ids"]) -> None: ...
global___QueryPendingRequestsResponse = QueryPendingRequestsResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> oracle.v1.oracle_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[oracle.v1.oracle_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryValidatorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryValidatorRequest = QueryValidatorRequest

class QueryValidatorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int

    @property
    def status(self) -> oracle.v1.oracle_pb2.ValidatorStatus: ...

    def __init__(self,
        *,
        status : typing.Optional[oracle.v1.oracle_pb2.ValidatorStatus] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> None: ...
global___QueryValidatorResponse = QueryValidatorResponse

class QueryReportersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryReportersRequest = QueryReportersRequest

class QueryReportersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REPORTER_FIELD_NUMBER: builtins.int

    @property
    def reporter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        reporter : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reporter",b"reporter"]) -> None: ...
global___QueryReportersResponse = QueryReportersResponse

class QueryActiveValidatorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryActiveValidatorsRequest = QueryActiveValidatorsRequest

class QueryActiveValidatorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATORS_FIELD_NUMBER: builtins.int

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.ActiveValidator]: ...

    def __init__(self,
        *,
        validators : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.ActiveValidator]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validators",b"validators"]) -> None: ...
global___QueryActiveValidatorsResponse = QueryActiveValidatorsResponse

class QueryRequestSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...
    calldata: typing.Text = ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        calldata : typing.Text = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ask_count",b"ask_count",u"calldata",b"calldata",u"min_count",b"min_count",u"oracle_script_id",b"oracle_script_id"]) -> None: ...
global___QueryRequestSearchRequest = QueryRequestSearchRequest

class QueryRequestSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_FIELD_NUMBER: builtins.int

    @property
    def request(self) -> global___QueryRequestResponse: ...

    def __init__(self,
        *,
        request : typing.Optional[global___QueryRequestResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"request",b"request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request",b"request"]) -> None: ...
global___QueryRequestSearchResponse = QueryRequestSearchResponse

class QueryRequestPriceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SYMBOLS_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int

    @property
    def symbols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...

    def __init__(self,
        *,
        symbols : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ask_count",b"ask_count",u"min_count",b"min_count",u"symbols",b"symbols"]) -> None: ...
global___QueryRequestPriceRequest = QueryRequestPriceRequest

class QueryRequestPriceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRICE_RESULTS_FIELD_NUMBER: builtins.int

    @property
    def price_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.PriceResult]: ...

    def __init__(self,
        *,
        price_results : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.PriceResult]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"price_results",b"price_results"]) -> None: ...
global___QueryRequestPriceResponse = QueryRequestPriceResponse

class QueryRequestVerificationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_ID_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...
    validator: typing.Text = ...
    request_id: builtins.int = ...
    external_id: builtins.int = ...
    reporter: typing.Text = ...
    signature: builtins.bytes = ...

    def __init__(self,
        *,
        chain_id : typing.Text = ...,
        validator : typing.Text = ...,
        request_id : builtins.int = ...,
        external_id : builtins.int = ...,
        reporter : typing.Text = ...,
        signature : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"external_id",b"external_id",u"reporter",b"reporter",u"request_id",b"request_id",u"signature",b"signature",u"validator",b"validator"]) -> None: ...
global___QueryRequestVerificationRequest = QueryRequestVerificationRequest

class QueryRequestVerificationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_ID_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...
    validator: typing.Text = ...
    request_id: builtins.int = ...
    external_id: builtins.int = ...
    data_source_id: builtins.int = ...

    def __init__(self,
        *,
        chain_id : typing.Text = ...,
        validator : typing.Text = ...,
        request_id : builtins.int = ...,
        external_id : builtins.int = ...,
        data_source_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"data_source_id",b"data_source_id",u"external_id",b"external_id",u"request_id",b"request_id",u"validator",b"validator"]) -> None: ...
global___QueryRequestVerificationResponse = QueryRequestVerificationResponse

class QueryRequestPoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_KEY_FIELD_NUMBER: builtins.int
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    request_key: typing.Text = ...
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    def __init__(self,
        *,
        request_key : typing.Text = ...,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"request_key",b"request_key"]) -> None: ...
global___QueryRequestPoolRequest = QueryRequestPoolRequest

class QueryRequestPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_POOL_ADDRESS_FIELD_NUMBER: builtins.int
    BALANCE_FIELD_NUMBER: builtins.int
    request_pool_address: typing.Text = ...

    @property
    def balance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        request_pool_address : typing.Text = ...,
        balance : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"balance",b"balance",u"request_pool_address",b"request_pool_address"]) -> None: ...
global___QueryRequestPoolResponse = QueryRequestPoolResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import ibc.core.channel.v1.genesis_pb2
import ibc.core.client.v1.genesis_pb2
import ibc.core.connection.v1.genesis_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_GENESIS_FIELD_NUMBER: builtins.int
    CONNECTION_GENESIS_FIELD_NUMBER: builtins.int
    CHANNEL_GENESIS_FIELD_NUMBER: builtins.int

    @property
    def client_genesis(self) -> ibc.core.client.v1.genesis_pb2.GenesisState: ...

    @property
    def connection_genesis(self) -> ibc.core.connection.v1.genesis_pb2.GenesisState: ...

    @property
    def channel_genesis(self) -> ibc.core.channel.v1.genesis_pb2.GenesisState: ...

    def __init__(self,
        *,
        client_genesis : typing.Optional[ibc.core.client.v1.genesis_pb2.GenesisState] = ...,
        connection_genesis : typing.Optional[ibc.core.connection.v1.genesis_pb2.GenesisState] = ...,
        channel_genesis : typing.Optional[ibc.core.channel.v1.genesis_pb2.GenesisState] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"channel_genesis",b"channel_genesis",u"client_genesis",b"client_genesis",u"connection_genesis",b"connection_genesis"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_genesis",b"channel_genesis",u"client_genesis",b"client_genesis",u"connection_genesis",b"connection_genesis"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Coin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...
    amount: typing.Text = ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        amount : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"denom",b"denom"]) -> None: ...
global___Coin = Coin

class DecCoin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...
    amount: typing.Text = ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        amount : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"denom",b"denom"]) -> None: ...
global___DecCoin = DecCoin

class IntProto(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INT_FIELD_NUMBER: builtins.int
    int: typing.Text = ...

    def __init__(self,
        *,
        int : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"int",b"int"]) -> None: ...
global___IntProto = IntProto

class DecProto(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DEC_FIELD_NUMBER: builtins.int
    dec: typing.Text = ...

    def __init__(self,
        *,
        dec : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dec",b"dec"]) -> None: ...
global___DecProto = DecProto



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEND_ENABLED_FIELD_NUMBER: builtins.int
    DEFAULT_SEND_ENABLED_FIELD_NUMBER: builtins.int
    default_send_enabled: builtins.bool = ...

    @property
    def send_enabled(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SendEnabled]: ...

    def __init__(self,
        *,
        send_enabled : typing.Optional[typing.Iterable[global___SendEnabled]] = ...,
        default_send_enabled : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"default_send_enabled",b"default_send_enabled",u"send_enabled",b"send_enabled"]) -> None: ...
global___Params = Params

class SendEnabled(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...
    enabled: builtins.bool = ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        enabled : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom",b"denom",u"enabled",b"enabled"]) -> None: ...
global___SendEnabled = SendEnabled

class Input(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: typing.Text = ...

    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        coins : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"coins",b"coins"]) -> None: ...
global___Input = Input

class Output(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: typing.Text = ...

    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        coins : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"coins",b"coins"]) -> None: ...
global___Output = Output

class Supply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOTAL_FIELD_NUMBER: builtins.int

    @property
    def total(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        total : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"total",b"total"]) -> None: ...
global___Supply = Supply

class DenomUnit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    EXPONENT_FIELD_NUMBER: builtins.int
    ALIASES_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...
    exponent: builtins.int = ...

    @property
    def aliases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        exponent : builtins.int = ...,
        aliases : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"aliases",b"aliases",u"denom",b"denom",u"exponent",b"exponent"]) -> None: ...
global___DenomUnit = DenomUnit

class Metadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DENOM_UNITS_FIELD_NUMBER: builtins.int
    BASE_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    description: typing.Text = ...
    base: typing.Text = ...
    display: typing.Text = ...

    @property
    def denom_units(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DenomUnit]: ...

    def __init__(self,
        *,
        description : typing.Text = ...,
        denom_units : typing.Optional[typing.Iterable[global___DenomUnit]] = ...,
        base : typing.Text = ...,
        display : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base",b"base",u"denom_units",b"denom_units",u"description",b"description",u"display",b"display"]) -> None: ...
global___Metadata = Metadata
